"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _constants = require("../constants");

var _declare_runtime_env = require("../declare_runtime_env");

var _import_resource = _interopRequireDefault(require("../import_resource"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var _default = ({
  resolveConfig,
  isClient
}) => {
  if (isClient) {
    throw new Error(`${_constants.message.serverAliasInClientCodeError}$resolve.aggregates`);
  }

  const imports = [`import '$resolve.guardOnlyServer'`];
  const constants = [];
  const exports = [``, `const aggregates = []`, ``];

  for (let index = 0; index < resolveConfig.aggregates.length; index++) {
    const aggregate = resolveConfig.aggregates[index];

    if ((0, _declare_runtime_env.checkRuntimeEnv)(aggregate.name)) {
      throw new Error(`${_constants.message.clientEnvError}.aggregates[${index}].name`);
    }

    constants.push(`const name_${index} = ${JSON.stringify(aggregate.name)}`);
    (0, _import_resource.default)({
      resourceName: `commands_${index}`,
      resourceValue: aggregate.commands,
      runtimeMode: _constants.RUNTIME_ENV_OPTIONS_ONLY,
      importMode: _constants.RESOURCE_ANY,
      instanceMode: _constants.IMPORT_INSTANCE,
      imports,
      constants
    });
    exports.push(`aggregates.push({`);
    exports.push(`  name: name_${index}`);
    exports.push(`, commands: commands_${index}`);
    (0, _import_resource.default)({
      resourceName: `serializeState_${index}`,
      resourceValue: aggregate.serializeState,
      runtimeMode: _constants.RUNTIME_ENV_OPTIONS_ONLY,
      importMode: _constants.RESOURCE_ANY,
      instanceMode: _constants.IMPORT_INSTANCE,
      instanceFallback: 'resolve-runtime/lib/common/defaults/json-serialize-state.js',
      imports,
      constants
    });
    exports.push(`, serializeState: serializeState_${index}`);
    (0, _import_resource.default)({
      resourceName: `deserializeState_${index}`,
      resourceValue: aggregate.deserializeState,
      runtimeMode: _constants.RUNTIME_ENV_OPTIONS_ONLY,
      importMode: _constants.RESOURCE_ANY,
      instanceMode: _constants.IMPORT_INSTANCE,
      instanceFallback: 'resolve-runtime/lib/common/defaults/json-deserialize-state.js',
      imports,
      constants
    });
    exports.push(`, deserializeState: deserializeState_${index}`);

    if (aggregate.projection != null) {
      (0, _import_resource.default)({
        resourceName: `projection_${index}`,
        resourceValue: aggregate.projection,
        runtimeMode: _constants.RUNTIME_ENV_OPTIONS_ONLY,
        importMode: _constants.RESOURCE_ANY,
        instanceMode: _constants.IMPORT_INSTANCE,
        calculateHash: 'resolve-aggregate-projection-hash',
        imports,
        constants
      });
      exports.push(`, projection: projection_${index}`);
      exports.push(`, invariantHash: projection_${index}_hash`);
    }

    (0, _import_resource.default)({
      resourceName: `encryption_${index}`,
      resourceValue: aggregate.encryption,
      runtimeMode: _constants.RUNTIME_ENV_NOWHERE,
      importMode: _constants.RESOURCE_ANY,
      instanceMode: _constants.IMPORT_INSTANCE,
      instanceFallback: 'resolve-runtime/lib/common/defaults/encryption.js',
      imports,
      constants
    });
    exports.push(`, encryption: encryption_${index}`);
    exports.push(`})`, ``);
  }

  exports.push(`export default aggregates`);
  return [...imports, ...constants, ...exports].join('\r\n');
};

exports.default = _default;
//# sourceMappingURL=$resolve.aggregates.js.map