"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _constants = require("../constants");

var _declare_runtime_env = require("../declare_runtime_env");

var _import_resource = _interopRequireDefault(require("../import_resource"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var _default = ({
  resolveConfig,
  isClient
}) => {
  if (isClient) {
    throw new Error(`${_constants.message.serverAliasInClientCodeError}$resolve.apiHandlers`);
  }

  const imports = [`import '$resolve.guardOnlyServer'`];
  const constants = [``];
  const exports = [``, `const apiHandlers = []`, ``];

  for (let index = 0; index < resolveConfig.apiHandlers.length; index++) {
    const apiHandler = resolveConfig.apiHandlers[index];

    if ((0, _declare_runtime_env.checkRuntimeEnv)(apiHandler.path)) {
      throw new Error(`${_constants.message.clientEnvError}.apiHandlers[${index}].path`);
    }

    constants.push(`const path_${index} = ${JSON.stringify(apiHandler.path)}`);

    if ((0, _declare_runtime_env.checkRuntimeEnv)(apiHandler.method)) {
      throw new Error(`${_constants.message.clientEnvError}.apiHandlers[${index}].method`);
    }

    constants.push(`const method_${index} = ${JSON.stringify(apiHandler.method)}`);
    (0, _import_resource.default)({
      resourceName: `handler_${index}`,
      resourceValue: apiHandler.handler,
      runtimeMode: _constants.RUNTIME_ENV_ANYWHERE,
      importMode: _constants.RESOURCE_ANY,
      instanceMode: _constants.IMPORT_INSTANCE,
      imports,
      constants
    });
    exports.push(`apiHandlers.push({`, `  path: path_${index}`);
    exports.push(`, handler: handler_${index}`);
    exports.push(`, method: method_${index}`);
    exports.push(`})`, ``);
  }

  exports.push(`export default apiHandlers`);
  return [...imports, ...constants, ...exports].join('\r\n');
};

exports.default = _default;
//# sourceMappingURL=$resolve.apiHandlers.js.map