"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _constants = require("../constants");

var _declare_runtime_env = require("../declare_runtime_env");

var _import_resource = _interopRequireDefault(require("../import_resource"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var _default = ({
  resolveConfig,
  isClient
}) => {
  if (isClient) {
    throw new Error(`${_constants.message.serverAliasInClientCodeError}.readModelConnectors`);
  }

  const imports = [`import '$resolve.guardOnlyServer'`, `import wrapReadModelConnector from 'resolve-runtime/lib/common/wrap-readmodel-connector'`];
  const constants = [``];
  const exports = [`const readModelConnectors = {}`];
  const readModelConnectorsNames = Object.keys(resolveConfig.readModelConnectors);

  for (let index = 0; index < readModelConnectorsNames.length; index++) {
    const readModelConnector = resolveConfig.readModelConnectors[readModelConnectorsNames[index]];
    constants.push(`const name_${index} = ${JSON.stringify(readModelConnectorsNames[index])}`);

    if (readModelConnector.module == null) {
      readModelConnector.module = 'resolve-runtime/lib/common/defaults/read-model-connector.js';
    }

    (0, _import_resource.default)({
      resourceName: `factory_s_${index}`,
      resourceValue: readModelConnector,
      runtimeMode: _constants.RUNTIME_ENV_ANYWHERE,
      importMode: _constants.RESOURCE_ANY,
      instanceMode: _constants.IMPORT_CONSTRUCTOR,
      imports,
      constants
    });

    if (readModelConnector.constructor === Object && readModelConnector.options != null) {
      constants.push(`const options_s_${index} = ${(0, _declare_runtime_env.injectRuntimeEnv)(readModelConnector.options)}`);
    } else {
      constants.push(`const options_s_${index} = null`);
    }

    constants.push(`
      const factory_${index} = (...args) => {
        return wrapReadModelConnector(factory_s_${index}(...args), options_s_${index}) 
      }
    `);
    exports.push(`readModelConnectors[name_${index}] = factory_${index}`);
  }

  exports.push(`export default readModelConnectors`);
  return [...imports, ...constants, ...exports].join('\r\n');
};

exports.default = _default;
//# sourceMappingURL=$resolve.readModelConnectors.js.map