"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _constants = require("../constants");

var _declare_runtime_env = require("../declare_runtime_env");

var _import_resource = _interopRequireDefault(require("../import_resource"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var _default = ({
  resolveConfig,
  isClient
}) => {
  if (isClient) {
    throw new Error(`${_constants.message.serverAliasInClientCodeError}$resolve.readModels`);
  }

  const imports = [`import '$resolve.guardOnlyServer'`];
  const constants = [``];
  const exports = [``, `const readModels = []`, ``];

  for (let index = 0; index < resolveConfig.readModels.length; index++) {
    const readModel = resolveConfig.readModels[index];

    if ((0, _declare_runtime_env.checkRuntimeEnv)(readModel.name)) {
      throw new Error(`${_constants.message.clientEnvError}.readModels[${index}].name`);
    }

    constants.push(`const name_${index} = ${JSON.stringify(readModel.name)}`);

    if ((0, _declare_runtime_env.checkRuntimeEnv)(readModel.connectorName)) {
      throw new Error(`${_constants.message.clientEnvError}.readModels[${index}].connectorName`);
    }

    constants.push(`const connectorName_${index} = ${JSON.stringify(readModel.connectorName)}`);
    (0, _import_resource.default)({
      resourceName: `resolvers_${index}`,
      resourceValue: readModel.resolvers,
      runtimeMode: _constants.RUNTIME_ENV_OPTIONS_ONLY,
      importMode: _constants.RESOURCE_ANY,
      instanceMode: _constants.IMPORT_INSTANCE,
      imports,
      constants
    });
    exports.push(`readModels.push({`, `  name: name_${index}`);
    exports.push(`, resolvers: resolvers_${index}`);
    exports.push(`, connectorName: connectorName_${index}`);
    (0, _import_resource.default)({
      resourceName: `projection_${index}`,
      resourceValue: readModel.projection,
      runtimeMode: _constants.RUNTIME_ENV_OPTIONS_ONLY,
      importMode: _constants.RESOURCE_ANY,
      instanceMode: _constants.IMPORT_INSTANCE,
      calculateHash: 'resolve-read-model-projection-hash',
      imports,
      constants
    });
    exports.push(`, projection: projection_${index}`);
    exports.push(`, invariantHash: projection_${index}_hash`);
    (0, _import_resource.default)({
      resourceName: `encryption_${index}`,
      resourceValue: readModel.encryption,
      runtimeMode: _constants.RUNTIME_ENV_NOWHERE,
      importMode: _constants.RESOURCE_ANY,
      instanceMode: _constants.IMPORT_INSTANCE,
      instanceFallback: 'resolve-runtime/lib/common/defaults/encryption.js',
      imports,
      constants
    });
    exports.push(`, encryption: encryption_${index}`);
    exports.push(`})`, ``);
  }

  exports.push(`export default readModels`);
  return [...imports, ...constants, ...exports].join('\r\n');
};

exports.default = _default;
//# sourceMappingURL=$resolve.readModels.js.map