"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _constants = require("../constants");

var _import_resource = _interopRequireDefault(require("../import_resource"));

var _declare_runtime_env = require("../declare_runtime_env");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var _default = ({
  resolveConfig,
  isClient
}) => {
  if (isClient) {
    throw new Error(`${_constants.message.serverAliasInClientCodeError}$resolve.sagas`);
  }

  const imports = [`import '$resolve.guardOnlyServer'`];
  const constants = [``];
  const exports = [``, `const sagas = []`, ``];

  for (let index = 0; index < resolveConfig.sagas.length; index++) {
    const saga = resolveConfig.sagas[index];

    if ((0, _declare_runtime_env.checkRuntimeEnv)(saga.name)) {
      throw new Error(`${_constants.message.clientEnvError}.sagas[${index}].name`);
    }

    constants.push(`const name_${index} = ${JSON.stringify(saga.name)}`);
    constants.push(`const connectorName_${index} = ${JSON.stringify(saga.connectorName)}`);
    (0, _import_resource.default)({
      resourceName: `source_${index}_original`,
      resourceValue: saga.source,
      runtimeMode: _constants.RUNTIME_ENV_ANYWHERE,
      importMode: _constants.RESOURCE_ANY,
      instanceMode: _constants.IMPORT_INSTANCE,
      calculateHash: 'resolve-saga-source-hash',
      imports,
      constants
    });

    if (saga.sideEffects != null) {
      (0, _import_resource.default)({
        resourceName: `sideEffects_${index}_original`,
        resourceValue: saga.sideEffects,
        runtimeMode: _constants.RUNTIME_ENV_ANYWHERE,
        importMode: _constants.RESOURCE_ANY,
        instanceMode: _constants.IMPORT_INSTANCE,
        calculateHash: 'resolve-saga-side-effects-hash',
        imports,
        constants
      });
    } else {
      constants.push(`const sideEffects_${index}_original = null`);
    }

    constants.push(`const handlers_${index} = sideEffects_${index}_original == null
      ? source_${index}_original.handlers
      : source_${index}_original
    `);
    constants.push(`const sideEffects_${index} = sideEffects_${index}_original == null
      ? source_${index}_original.sideEffects
      : sideEffects_${index}_original
    `);
    constants.push(`const invariantHash_${index} = sideEffects_${index}_original != null
      ? source_${index}_original_hash + sideEffects_${index}_original_hash
      : source_${index}_original_hash
    `);
    (0, _import_resource.default)({
      resourceName: `encryption_${index}`,
      resourceValue: saga.encryption,
      runtimeMode: _constants.RUNTIME_ENV_NOWHERE,
      importMode: _constants.RESOURCE_ANY,
      instanceMode: _constants.IMPORT_INSTANCE,
      instanceFallback: 'resolve-runtime/lib/common/defaults/encryption.js',
      imports,
      constants
    }); // FIXME: why 'handlers' not 'projection' here?

    exports.push(`sagas.push({`, `  name: name_${index}`);
    exports.push(`, connectorName: connectorName_${index}`);
    exports.push(`, handlers: handlers_${index}`);
    exports.push(`, sideEffects: sideEffects_${index}`);
    exports.push(`, invariantHash: invariantHash_${index}`);
    exports.push(`, encryption: encryption_${index}`);
    exports.push(`})`, ``);
  }

  exports.push(`export default sagas`);
  return [...imports, ...constants, ...exports].join('\r\n');
};

exports.default = _default;
//# sourceMappingURL=$resolve.sagas.js.map