"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _constants = require("../constants");

var _declare_runtime_env = _interopRequireWildcard(require("../declare_runtime_env"));

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const CLIENT_ENV_KEY = '__CLIENT_ENV__';

var _default = ({
  resolveConfig,
  isClient
}) => {
  if (isClient) {
    throw new Error(`${_constants.message.serverAliasInClientCodeError}$resolve.seedClientEnvs`);
  }

  if (!resolveConfig.hasOwnProperty(CLIENT_ENV_KEY)) {
    Object.defineProperty(resolveConfig, CLIENT_ENV_KEY, {
      value: {
        showInformationWarn: true,
        exposedEnvs: new Set()
      },
      enumerable: false
    });
  }

  const clientEnvs = [(0, _declare_runtime_env.default)('RESOLVE_UPLOADER_CDN_URL')];
  const configEnvs = [resolveConfig.customConstants, resolveConfig.staticPath, resolveConfig.rootPath, resolveConfig.jwtCookie, ...(Array.isArray(resolveConfig.viewModels) ? resolveConfig.viewModels.map(viewModel => viewModel.projection) : []), ...(resolveConfig.clientImports != null && Object(resolveConfig.clientImports) === resolveConfig.clientImports ? Object.keys(resolveConfig.clientImports).map(key => resolveConfig.clientImports[key]) : [])];
  void JSON.stringify(configEnvs, (key, value) => {
    if ((0, _declare_runtime_env.checkRuntimeEnv)(value)) {
      clientEnvs.push(value);
    }

    return value;
  });
  const seededEnvKeys = new Set();

  for (let index = clientEnvs.length - 1; index >= 0; index--) {
    const key = `${clientEnvs[index]}`;

    if (seededEnvKeys.has(key)) {
      clientEnvs.splice(index, 1);
    } else {
      seededEnvKeys.add(key);
    }
  }
  /* eslint-disable no-console */


  if (clientEnvs.length > 0) {
    if (resolveConfig[CLIENT_ENV_KEY].showInformationWarn) {
      console.log('Following environment variables will be sent into browser:');
      resolveConfig[CLIENT_ENV_KEY].showInformationWarn = false;
    }

    for (const env of clientEnvs) {
      if (!resolveConfig[CLIENT_ENV_KEY].exposedEnvs.has(env)) {
        console.log(` * ${env}`);
        resolveConfig[CLIENT_ENV_KEY].exposedEnvs.add(env);
      }
    }
  }
  /* eslint-enable no-console */


  const exports = [`import '$resolve.guardOnlyServer'`, `const seedClientEnvs = {}`];

  for (const clientEnv of clientEnvs) {
    exports.push(`Object.defineProperty(
      seedClientEnvs,
      ${JSON.stringify(clientEnv)},
      {
        enumerable: true,
        get: () => {
          return ${(0, _declare_runtime_env.injectRuntimeEnv)(clientEnv)}
        }
      }
    )`);
  }

  exports.push(`Object.freeze(seedClientEnvs)`, ``, `export default seedClientEnvs`);
  return exports.join('\r\n');
};

exports.default = _default;
//# sourceMappingURL=$resolve.seedClientEnvs.js.map