"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _constants = require("../constants");

var _declare_runtime_env = require("../declare_runtime_env");

var _import_resource = _interopRequireDefault(require("../import_resource"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var _default = ({
  resolveConfig,
  isClient
}) => {
  const imports = [];
  const constants = [];
  const exports = [`const viewModels = []`, ``];

  for (let index = 0; index < resolveConfig.viewModels.length; index++) {
    const viewModel = resolveConfig.viewModels[index];

    if ((0, _declare_runtime_env.checkRuntimeEnv)(viewModel.name)) {
      throw new Error(`${_constants.message.clientEnvError}.viewModels[${index}].name`);
    }

    constants.push(`const name_${index} = ${JSON.stringify(viewModel.name)}`);
    (0, _import_resource.default)({
      resourceName: `projection_${index}`,
      resourceValue: viewModel.projection,
      runtimeMode: _constants.RUNTIME_ENV_OPTIONS_ONLY,
      importMode: _constants.RESOURCE_ANY,
      instanceMode: _constants.IMPORT_INSTANCE,
      calculateHash: !isClient ? 'resolve-view-model-projection-hash' : null,
      injectRuntimeOptions: isClient ? true : null,
      imports,
      constants
    });
    (0, _import_resource.default)({
      resourceName: `deserializeState_${index}`,
      resourceValue: viewModel.deserializeState,
      runtimeMode: _constants.RUNTIME_ENV_OPTIONS_ONLY,
      importMode: _constants.RESOURCE_ANY,
      instanceMode: _constants.IMPORT_INSTANCE,
      instanceFallback: 'resolve-runtime/lib/common/defaults/json-deserialize-state.js',
      injectRuntimeOptions: isClient ? true : null,
      imports,
      constants
    });
    exports.push(`viewModels.push({`, `  name: name_${index}`, `, projection: projection_${index}`, `, deserializeState: deserializeState_${index}`);

    if (!isClient) {
      exports.push(`, invariantHash: projection_${index}_hash`);
      (0, _import_resource.default)({
        resourceName: `serializeState_${index}`,
        resourceValue: viewModel.serializeState,
        runtimeMode: _constants.RUNTIME_ENV_OPTIONS_ONLY,
        importMode: _constants.RESOURCE_ANY,
        instanceMode: _constants.IMPORT_INSTANCE,
        instanceFallback: 'resolve-runtime/lib/common/defaults/json-serialize-state.js',
        imports,
        constants
      });
      exports.push(`, serializeState: serializeState_${index}`);
      (0, _import_resource.default)({
        resourceName: `resolver_${index}`,
        resourceValue: viewModel.resolver,
        runtimeMode: _constants.RUNTIME_ENV_OPTIONS_ONLY,
        importMode: _constants.RESOURCE_ANY,
        instanceMode: _constants.IMPORT_INSTANCE,
        instanceFallback: 'resolve-runtime/lib/common/defaults/view-model-resolver.js',
        imports,
        constants
      });
      exports.push(`, resolver: resolver_${index}`);
      (0, _import_resource.default)({
        resourceName: `encryption_${index}`,
        resourceValue: viewModel.encryption,
        runtimeMode: _constants.RUNTIME_ENV_NOWHERE,
        importMode: _constants.RESOURCE_ANY,
        instanceMode: _constants.IMPORT_INSTANCE,
        instanceFallback: 'resolve-runtime/lib/common/defaults/encryption.js',
        imports,
        constants
      });
      exports.push(`, encryption: encryption_${index}`);
    }

    exports.push(`})`, ``);
  }

  if (!isClient) {
    exports.push(`
      let AsyncGeneratorFunction = {}
      let GeneratorFunction = {}
      let AsyncFunction = {}

      try {
        eval('AsyncGeneratorFunction = (async function* name(){}).constructor')
      } catch(err) {}

      try {
        eval('GeneratorFunction = (function*(){}).constructor')
      } catch(err) {}

      try {
        eval('AsyncFunction = (async function(){}).constructor')
      } catch(err) {}

      const checkValidProjectionFunction = (func) => {
        if(typeof func !== 'function') {
          return false
        }
        if(func.constructor === GeneratorFunction) {
          return false
        }
        if(func.constructor === AsyncFunction) {
          return false
        }
        if(func.constructor === AsyncGeneratorFunction) {
          return false
        }
        return true
      }
    
      for(const { projection } of viewModels) {
        for(const key of Object.keys(projection)) {
          if(!checkValidProjectionFunction(projection[key])) {
            throw new Error(
              \`A Projection handler "\${key}" cannot be a generator or/and asynchronous function\`
            )
          }
        }
      }
    `);
  }

  exports.push(`export default viewModels`);
  return [...imports, ...constants, ...exports].join('\r\n');
};

exports.default = _default;
//# sourceMappingURL=$resolve.viewModels.js.map