"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _esmWebpackPlugin = _interopRequireDefault(require("@purtuga/esm-webpack-plugin"));

var _path = _interopRequireDefault(require("path"));

var _get_client_entries = _interopRequireDefault(require("./get_client_entries"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const attachWebpackConfigsClientEntries = (resolveConfig, baseConfig, configs, isClient) => {
  const {
    iifeEntries,
    commonjsEntries,
    esmEntries
  } = (0, _get_client_entries.default)(resolveConfig, isClient);

  if (iifeEntries.length > 0) {
    configs.push({ ...baseConfig,
      name: `${isClient ? 'Client' : 'Server'} IIFE entries`,
      entry: iifeEntries.reduce((acc, {
        inputFile,
        outputFile
      }) => {
        acc[outputFile] = `${_path.default.resolve(__dirname, './alias/$resolve.clientEntry.js')}?inputFile=${inputFile}`;
        return acc;
      }, {})
    });
  }

  if (commonjsEntries.length > 0) {
    configs.push({ ...baseConfig,
      name: `${isClient ? 'Client' : 'Server'} CommonJS entries`,
      entry: commonjsEntries.reduce((acc, {
        inputFile,
        outputFile
      }) => {
        acc[outputFile] = `${_path.default.resolve(__dirname, './alias/$resolve.clientEntry.js')}?inputFile=${inputFile}`;
        return acc;
      }, {}),
      output: { ...baseConfig.output,
        libraryTarget: 'commonjs-module'
      }
    });
  }

  if (esmEntries.length > 0) {
    configs.push({ ...baseConfig,
      name: `${isClient ? 'Client' : 'Server'} Client ESM entries`,
      entry: esmEntries.reduce((acc, {
        inputFile,
        outputFile
      }) => {
        acc[outputFile] = `${_path.default.resolve(__dirname, './alias/$resolve.clientEntry.js')}?inputFile=${inputFile}`;
        return acc;
      }, {}),
      output: { ...baseConfig.output,
        libraryTarget: 'var',
        library: '__RESOLVE_ENTRY__'
      },
      plugins: [...baseConfig.plugins, new _esmWebpackPlugin.default()]
    });
  }
};

var _default = attachWebpackConfigsClientEntries;
exports.default = _default;
//# sourceMappingURL=attach_webpack_configs_client_entries.js.map