"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _fsExtra = _interopRequireDefault(require("fs-extra"));

var _path = _interopRequireDefault(require("path"));

var _webpack = _interopRequireDefault(require("webpack"));

var _getLog = _interopRequireDefault(require("./getLog"));

var _get_webpack_configs = _interopRequireDefault(require("./get_webpack_configs"));

var _write_package_jsons_for_assemblies = _interopRequireDefault(require("./write_package_jsons_for_assemblies"));

var _get_peer_dependencies = _interopRequireDefault(require("./get_peer_dependencies"));

var _show_build_info = _interopRequireDefault(require("./show_build_info"));

var _copy_env_to_dist = _interopRequireDefault(require("./copy_env_to_dist"));

var _validate_config = _interopRequireDefault(require("./validate_config"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const log = (0, _getLog.default)('build');

var _default = async (resolveConfig, adjustWebpackConfigs) => {
  log.debug('Starting "build" mode');
  (0, _validate_config.default)(resolveConfig);
  const nodeModulesByAssembly = new Map();
  const webpackConfigs = await (0, _get_webpack_configs.default)({
    resolveConfig,
    nodeModulesByAssembly,
    adjustWebpackConfigs
  });
  const peerDependencies = (0, _get_peer_dependencies.default)();
  const compiler = (0, _webpack.default)(webpackConfigs);

  _fsExtra.default.copySync(_path.default.resolve(process.cwd(), resolveConfig.staticDir), _path.default.resolve(process.cwd(), resolveConfig.distDir, './client'));

  return await new Promise((resolve, reject) => {
    compiler.run((err, {
      stats
    }) => {
      console.log(' '); // eslint-disable-line no-console

      stats.forEach(_show_build_info.default.bind(null, err));
      (0, _write_package_jsons_for_assemblies.default)(resolveConfig.distDir, nodeModulesByAssembly, peerDependencies);
      (0, _copy_env_to_dist.default)(resolveConfig.distDir);
      const hasNoErrors = stats.reduce((acc, val) => acc && val != null && !val.hasErrors(), true);

      if (hasNoErrors) {
        resolve();
        log.debug('Building complete');
      } else {
        reject(stats.toString(''));
      }
    });
  });
};

exports.default = _default;
//# sourceMappingURL=build_mode.js.map