"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _isomorphicFetch = _interopRequireDefault(require("isomorphic-fetch"));

var _prepare_urls = _interopRequireDefault(require("./prepare_urls"));

var _path = _interopRequireDefault(require("path"));

var _declare_runtime_env = require("./declare_runtime_env");

var _process_manager = require("./process_manager");

var _validate_config = _interopRequireDefault(require("./validate_config"));

var _get_webpack_configs = _interopRequireDefault(require("./get_webpack_configs"));

var _get_peer_dependencies = _interopRequireDefault(require("./get_peer_dependencies"));

var _webpack = _interopRequireDefault(require("webpack"));

var _fsExtra = _interopRequireDefault(require("fs-extra"));

var _show_build_info = _interopRequireDefault(require("./show_build_info"));

var _write_package_jsons_for_assemblies = _interopRequireDefault(require("./write_package_jsons_for_assemblies"));

var _copy_env_to_dist = _interopRequireDefault(require("./copy_env_to_dist"));

var _getLog = _interopRequireDefault(require("./getLog"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const log = (0, _getLog.default)('custom');

const generateCustomMode = (getConfig, apiHandlerUrl, runAfterLaunch) => (resolveConfig, options, adjustWebpackConfigs) => new Promise(async (resolve, reject) => {
  try {
    log.debug(`Starting "${apiHandlerUrl}" mode`);
    const config = await getConfig(resolveConfig, options);
    (0, _validate_config.default)(config);
    const nodeModulesByAssembly = new Map();
    const webpackConfigs = await (0, _get_webpack_configs.default)({
      resolveConfig: config,
      nodeModulesByAssembly,
      adjustWebpackConfigs
    });
    const peerDependencies = (0, _get_peer_dependencies.default)();
    const compiler = (0, _webpack.default)(webpackConfigs);

    _fsExtra.default.copySync(_path.default.resolve(process.cwd(), config.staticDir), _path.default.resolve(process.cwd(), config.distDir, './client'));

    await new Promise((resolve, reject) => {
      compiler.run((err, {
        stats
      }) => {
        console.log(' '); // eslint-disable-line no-console

        stats.forEach(_show_build_info.default.bind(null, err));
        (0, _write_package_jsons_for_assemblies.default)(config.distDir, nodeModulesByAssembly, peerDependencies);
        (0, _copy_env_to_dist.default)(config.distDir);
        const hasNoErrors = stats.reduce((acc, val) => acc && val != null && !val.hasErrors(), true);
        void (hasNoErrors ? resolve() : reject(stats.toString('')));
      });
    });

    const serverPath = _path.default.resolve(process.cwd(), _path.default.join(config.distDir, './common/local-entry/local-entry.js'));

    const resolveLaunchId = Math.floor(Math.random() * 1000000000);
    const server = (0, _process_manager.processRegister)(['node', serverPath], {
      cwd: process.cwd(),
      maxRestarts: 0,
      kill: 5000,
      stdio: 'inherit',
      env: { ...process.env,
        RESOLVE_LAUNCH_ID: resolveLaunchId
      }
    });
    server.on('crash', reject);
    server.start();
    log.debug(`Server process pid: ${server.pid}`);
    let broker = {
      stop: callback => callback()
    };

    if (config.eventBroker.launchBroker) {
      const brokerPath = _path.default.resolve(process.cwd(), _path.default.join(config.distDir, './common/local-entry/local-bus-broker.js'));

      broker = (0, _process_manager.processRegister)(['node', brokerPath], {
        cwd: process.cwd(),
        maxRestarts: 0,
        kill: 5000,
        stdio: 'inherit',
        env: { ...process.env,
          RESOLVE_LAUNCH_ID: resolveLaunchId
        }
      });
      broker.on('crash', reject);
      broker.start(resolve);
      log.debug(`Bus broker process pid: ${broker.pid}`);
    }

    const port = Number((0, _declare_runtime_env.checkRuntimeEnv)(config.port) ? // eslint-disable-next-line no-new-func
    new Function(`return ${(0, _declare_runtime_env.injectRuntimeEnv)(config.port)}`)() : config.port);
    let lastError = null;

    if (apiHandlerUrl != null) {
      const urls = (0, _prepare_urls.default)('http', '0.0.0.0', port, config.rootPath);
      const baseUrl = urls.localUrlForBrowser;
      const url = `${baseUrl}api/${apiHandlerUrl}`;

      while (true) {
        try {
          const response = await (0, _isomorphicFetch.default)(url);
          const result = await response.text();

          if (result !== 'ok') {
            lastError = [`Error while communication with reSolve HTTP server at port ${port}`, `Maybe multiple instances of reSolve applications trying to run with similar port`, `${response.status}: ${response.statusText}`, `${result}`].join('\n');
          }

          break;
        } catch (e) {}

        await new Promise(resolve => setTimeout(resolve, 500));
      }
    }

    if (typeof runAfterLaunch === 'function') {
      try {
        await runAfterLaunch(options, config);
      } catch (error) {
        lastError = error;
      }
    }

    await Promise.all([new Promise(resolve => server.stop(resolve)), new Promise(resolve => broker.stop(resolve))]);
    log.debug('Server was stopped');
    log.debug('Bus broker was stopped');

    if (lastError != null) {
      throw lastError;
    }

    resolve();
  } catch (error) {
    reject(error);
  }
});

var _default = generateCustomMode;
exports.default = _default;
//# sourceMappingURL=generate_custom_mode.js.map