"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _path = _interopRequireDefault(require("path"));

var _esmWebpackPlugin = _interopRequireDefault(require("@purtuga/esm-webpack-plugin"));

var _attach_webpack_configs_client_entries = _interopRequireDefault(require("./attach_webpack_configs_client_entries"));

var _get_modules_dirs = _interopRequireDefault(require("./get_modules_dirs"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const getClientWebpackConfigs = ({
  resolveConfig,
  alias
}) => {
  const distDir = _path.default.resolve(process.cwd(), resolveConfig.distDir);

  const isClient = true;
  const clientTransformBabelOptions = {
    cacheDirectory: true,
    babelrc: false,
    presets: ['@babel/preset-env', '@babel/preset-react'],
    plugins: ['@babel/plugin-proposal-class-properties', '@babel/plugin-proposal-export-default-from', '@babel/plugin-proposal-export-namespace-from', ['@babel/plugin-transform-runtime', {
      corejs: false,
      helpers: true,
      regenerator: true,
      useESModules: false
    }]]
  };
  const baseClientConfig = {
    name: 'ClientConfigName',
    entry: {},
    context: _path.default.resolve(process.cwd()),
    mode: resolveConfig.mode,
    performance: false,
    devtool: 'source-map',
    target: 'web',
    output: {
      path: distDir,
      filename: '[name]',
      devtoolModuleFilenameTemplate: '[namespace][resource-path]',
      devtoolFallbackModuleFilenameTemplate: '[namespace][resource-path]?[hash]'
    },
    resolve: {
      modules: (0, _get_modules_dirs.default)(),
      alias
    },
    module: {
      rules: [{
        test: Object.values(alias),
        use: [{
          loader: require.resolve('babel-loader'),
          options: clientTransformBabelOptions
        }, {
          loader: require.resolve('./val_query_loader'),
          options: {
            resolveConfig,
            isClient
          }
        }]
      }, {
        test: /\.js$/,
        use: {
          loader: require.resolve('babel-loader'),
          options: {
            cacheDirectory: true
          }
        },
        exclude: [/node_modules/, ...(0, _get_modules_dirs.default)({
          isAbsolutePath: true
        }), _path.default.resolve(__dirname, '../lib'), _path.default.resolve(__dirname, '../es')]
      }, {
        test: /resolve-runtime[\\/](?!node_modules).*?\.js$/,
        use: {
          loader: require.resolve('babel-loader'),
          options: clientTransformBabelOptions
        }
      }]
    },
    plugins: []
  };
  const clientConfigs = [{ ...baseClientConfig,
    name: 'Shared client ESM chunks',
    entry: {
      'common/shared/client-chunk.js': _path.default.resolve(__dirname, './alias/$resolve.clientChunk.js'),
      'common/shared/client-imports.js': _path.default.resolve(__dirname, './alias/$resolve.clientImports.js'),
      'common/shared/view-models.js': _path.default.resolve(__dirname, './alias/$resolve.viewModels.js')
    },
    output: { ...baseClientConfig.output,
      libraryTarget: 'var',
      library: '__RESOLVE_ENTRY__'
    },
    plugins: [...baseClientConfig.plugins, new _esmWebpackPlugin.default()]
  }];
  (0, _attach_webpack_configs_client_entries.default)(resolveConfig, baseClientConfig, clientConfigs, true);
  return clientConfigs;
};

var _default = getClientWebpackConfigs;
exports.default = _default;
//# sourceMappingURL=get_webpack_client_configs.js.map