"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _chalk = _interopRequireDefault(require("chalk"));

var _isomorphicFetch = _interopRequireDefault(require("isomorphic-fetch"));

var _opn = _interopRequireDefault(require("opn"));

var _path = _interopRequireDefault(require("path"));

var _use_yarn = _interopRequireDefault(require("./use_yarn"));

var _prepare_urls = _interopRequireDefault(require("./prepare_urls"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const openBrowser = async (port, rootPath) => {
  let applicationName = 'application';

  try {
    applicationName = require(_path.default.join(process.cwd(), 'package.json')).name;
  } catch (e) {}

  const urls = (0, _prepare_urls.default)('http', '0.0.0.0', port, rootPath);
  const url = urls.localUrlForBrowser;
  /* eslint-disable no-console */

  while (true) {
    try {
      await new Promise(resolve => setTimeout(resolve, 1000));
      await (0, _isomorphicFetch.default)(url);
      break;
    } catch (error) {
      console.log(`Server is still loading - please wait...`);
    }
  }

  Promise.resolve().then(() => (0, _opn.default)(url, {
    app: process.env.BROWSER
  })).catch(() => {});
  console.log();
  console.log(`You can now view ${_chalk.default.bold(applicationName)} in the browser.`);
  console.log();

  if (urls.lanUrlForTerminal) {
    console.log(`  ${_chalk.default.bold('Local:')}            ${urls.localUrlForTerminal}`);
    console.log(`  ${_chalk.default.bold('On Your Network:')}  ${urls.lanUrlForTerminal}`);
  } else {
    console.log(`  ${urls.localUrlForTerminal}`);
  }

  if (process.env.NODE_ENV !== 'production') {
    console.log();
    console.log('Note that the development build is not optimized.');
    console.log('To create a production build, use:');
    console.log(`  ${_chalk.default.cyan(`${(0, _use_yarn.default)() ? 'yarn build' : 'npm run build'}`)}.`);
    console.log(`  ${_chalk.default.cyan(`${(0, _use_yarn.default)() ? 'yarn start' : 'npm start'}`)}.`);
    console.log();
  }
  /* eslint-enable no-console */

};

var _default = openBrowser;
exports.default = _default;
//# sourceMappingURL=open_browser.js.map