"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.processStopAll = exports.processRegister = exports.processFail = void 0;

var _respawn = _interopRequireDefault(require("respawn"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const errors = [];
const processes = [];

const processFail = error => {
  errors.push(error);
};

exports.processFail = processFail;

const processRegister = (command, opts) => {
  const process = (0, _respawn.default)(command, opts);
  processes.push(process);
  return process;
};

exports.processRegister = processRegister;

const processStopAll = error => {
  if (error != null) {
    errors.push(error);
  }

  const promises = [];

  for (const process of processes) {
    promises.push(new Promise(resolve => {
      if (process.stop) {
        process.stop(resolve);
      } else {
        resolve();
      }
    }));
  }

  processes.length = 0;
  return Promise.all(promises).then(() => {
    let code = 0;

    for (const error of errors) {
      code = 1; // eslint-disable-next-line no-console

      console.error(error);
    }

    process.exit(code);
  });
};

exports.processStopAll = processStopAll;
process.on('SIGINT', processStopAll);
//# sourceMappingURL=process_manager.js.map