"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _testcafeBrowserTools = require("testcafe-browser-tools");

var _child_process = require("child_process");

var _merge = _interopRequireDefault(require("./merge"));

var _generate_custom_mode = _interopRequireDefault(require("./generate_custom_mode"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const getConfig = async (resolveConfig, options) => {
  if (options == null || options.constructor !== Object) {
    throw new Error('Invalid run-testcafe options');
  }

  const {
    functionalTestsDir,
    browser,
    customArgs,
    timeout
  } = options;

  if (functionalTestsDir == null || functionalTestsDir.constructor !== String) {
    throw new Error('Options field "functionalTestsDir" must be string');
  }

  if (browser != null && browser.constructor !== String) {
    throw new Error('Options field "browser" should be string or null');
  }

  if (timeout != null && timeout.constructor !== Number) {
    throw new Error('Options field "timeout" should be number or null');
  }

  if (customArgs != null && !Array.isArray(customArgs)) {
    throw new Error('Options field "customArgs" must be array of strings');
  }

  const config = (0, _merge.default)(resolveConfig, {
    apiHandlers: [{
      handler: 'resolve-runtime/lib/local/query-is-ready-handler.js',
      path: '/api/query-is-ready',
      method: 'GET'
    }]
  });
  return config;
};

const runAfterLaunch = async options => {
  let {
    functionalTestsDir,
    browser,
    customArgs,
    timeout
  } = options;
  browser = browser != null ? browser : Object.keys(await (0, _testcafeBrowserTools.getInstallations)())[0];
  timeout = timeout != null ? timeout : 20000;
  customArgs = customArgs != null ? customArgs : [];

  try {
    return (0, _child_process.execSync)([`npx testcafe ${browser}`, `${functionalTestsDir}`, `--app-init-delay ${timeout}`, `--selector-timeout ${timeout}`, `--assertion-timeout ${timeout}`, `--page-load-timeout ${timeout}`, browser === 'remote' ? ' --qr-code' : '', ...customArgs].join(' '), {
      stdio: 'inherit'
    });
  } catch (e) {
    // eslint-disable-next-line no-throw-literal
    throw '';
  }
};

const runTestcafeMode = async ({
  resolveConfig,
  adjustWebpackConfigs,
  functionalTestsDir,
  browser,
  customArgs,
  timeout
}) => (0, _generate_custom_mode.default)(getConfig, 'query-is-ready', runAfterLaunch)(resolveConfig, {
  functionalTestsDir,
  browser,
  customArgs,
  timeout
}, adjustWebpackConfigs);

var _default = runTestcafeMode;
exports.default = _default;
//# sourceMappingURL=run_testcafe.js.map