"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _fsExtra = _interopRequireDefault(require("fs-extra"));

var _path = _interopRequireDefault(require("path"));

var _webpack = _interopRequireDefault(require("webpack"));

var _getLog = _interopRequireDefault(require("./getLog"));

var _get_webpack_configs = _interopRequireDefault(require("./get_webpack_configs"));

var _write_package_jsons_for_assemblies = _interopRequireDefault(require("./write_package_jsons_for_assemblies"));

var _declare_runtime_env = require("./declare_runtime_env");

var _get_peer_dependencies = _interopRequireDefault(require("./get_peer_dependencies"));

var _show_build_info = _interopRequireDefault(require("./show_build_info"));

var _copy_env_to_dist = _interopRequireDefault(require("./copy_env_to_dist"));

var _validate_config = _interopRequireDefault(require("./validate_config"));

var _open_browser = _interopRequireDefault(require("./open_browser"));

var _process_manager = require("./process_manager");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const log = (0, _getLog.default)('watch');

var _default = async (resolveConfig, adjustWebpackConfigs) => {
  log.debug('Starting "watch" mode');
  (0, _validate_config.default)(resolveConfig);
  const nodeModulesByAssembly = new Map();
  const webpackConfigs = await (0, _get_webpack_configs.default)({
    resolveConfig,
    nodeModulesByAssembly,
    adjustWebpackConfigs
  });
  const peerDependencies = (0, _get_peer_dependencies.default)();
  const compiler = (0, _webpack.default)(webpackConfigs);

  const serverPath = _path.default.resolve(process.cwd(), _path.default.join(resolveConfig.distDir, './common/local-entry/local-entry.js'));

  const resolveLaunchId = Math.floor(Math.random() * 1000000000);
  const server = (0, _process_manager.processRegister)(['node', serverPath], {
    cwd: process.cwd(),
    maxRestarts: 0,
    kill: 5000,
    stdio: 'inherit',
    env: { ...process.env,
      RESOLVE_LAUNCH_ID: resolveLaunchId
    }
  });
  let broker = null;

  if (resolveConfig.eventBroker.launchBroker) {
    const brokerPath = _path.default.resolve(process.cwd(), _path.default.join(resolveConfig.distDir, './common/local-entry/local-bus-broker.js'));

    broker = (0, _process_manager.processRegister)(['node', brokerPath], {
      cwd: process.cwd(),
      maxRestarts: 0,
      kill: 5000,
      stdio: 'inherit',
      env: { ...process.env,
        RESOLVE_LAUNCH_ID: resolveLaunchId
      }
    });
  }

  process.env.RESOLVE_SERVER_FIRST_START = 'true';
  process.env.RESOLVE_SERVER_OPEN_BROWSER = 'true';

  _fsExtra.default.copySync(_path.default.resolve(process.cwd(), resolveConfig.staticDir), _path.default.resolve(process.cwd(), resolveConfig.distDir, './client'));

  const stdin = process.openStdin();
  stdin.addListener('data', data => {
    if (data.toString().indexOf('rs') !== -1) {
      process.env.RESOLVE_SERVER_FIRST_START = 'false';
      server.stop(() => server.start());
    }
  });
  return await new Promise(() => {
    compiler.watch({
      aggregateTimeout: 1000,
      poll: 1000
    }, (err, {
      stats
    }) => {
      console.log(' '); // eslint-disable-line no-console

      stats.forEach(_show_build_info.default.bind(null, err));
      (0, _write_package_jsons_for_assemblies.default)(resolveConfig.distDir, nodeModulesByAssembly, peerDependencies);
      (0, _copy_env_to_dist.default)(resolveConfig.distDir);
      const hasErrors = stats.reduce((acc, val) => acc || val != null && val.hasErrors(), false);
      const port = Number((0, _declare_runtime_env.checkRuntimeEnv)(resolveConfig.port) ? // eslint-disable-next-line no-new-func
      new Function(`return ${(0, _declare_runtime_env.injectRuntimeEnv)(resolveConfig.port)}`)() : resolveConfig.port);

      if (hasErrors) {
        server.stop();
      } else {
        if (server.status === 'running') {
          process.env.RESOLVE_SERVER_FIRST_START = 'false';
          server.stop(() => server.start());
        } else {
          if (resolveConfig.eventBroker.launchBroker) {
            broker.start();
            log.debug(`Bus broker process pid: ${broker.pid}`);
          }

          server.start();
          log.debug(`Server process pid: ${server.pid}`);
          const isOpenBrowser = process.env.RESOLVE_SERVER_OPEN_BROWSER === 'true';
          const serverFirstStart = process.env.RESOLVE_SERVER_FIRST_START === 'true';

          if (isOpenBrowser && serverFirstStart) {
            log.debug('Opening browser');
            (0, _open_browser.default)(port, resolveConfig.rootPath).catch(() => {});
            log.debug('Browser was opened');
          }
        }
      }
    });
  });
};

exports.default = _default;
//# sourceMappingURL=watch_mode.js.map