"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _fs = _interopRequireDefault(require("fs"));

var _path = _interopRequireDefault(require("path"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const writePackageJsonsForAssemblies = (distDir, nodeModulesByAssembly, peerDependencies) => {
  const applicationPackageJson = JSON.parse(_fs.default.readFileSync(_path.default.resolve(process.cwd(), 'package.json')));

  const resolveRuntimePackageJson = require('resolve-runtime/package.json');

  for (const [packageJsonPath, nodeModules] of nodeModulesByAssembly.entries()) {
    const absolutePackageJsonPath = _path.default.resolve(process.cwd(), distDir, packageJsonPath);

    const syntheticName = packageJsonPath.replace('/package.json', '').replace(/[^\w\d-]/g, '-');
    const resultNodeModules = new Set([...Array.from(nodeModules), ...Array.from(peerDependencies)]);
    const assemblyPackageJson = {
      name: `${applicationPackageJson.name}-${syntheticName}`,
      private: true,
      version: applicationPackageJson.version,
      main: './index.js',
      dependencies: Array.from(resultNodeModules).reduce((acc, val) => {
        if (applicationPackageJson.dependencies.hasOwnProperty(val)) {
          acc[val] = applicationPackageJson.dependencies[val];
        } else if (resolveRuntimePackageJson.dependencies.hasOwnProperty(val) && nodeModules.has(val)) {
          acc[val] = resolveRuntimePackageJson.dependencies[val];
        }

        return acc;
      }, {})
    };

    _fs.default.writeFileSync(absolutePackageJsonPath, JSON.stringify(assemblyPackageJson, null, 2));
  }
};

var _default = writePackageJsonsForAssemblies;
exports.default = _default;
//# sourceMappingURL=write_package_jsons_for_assemblies.js.map